@@ -17,7 +17,7 @@ from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
 
-from .literals import ChangeType, FormatType, locationType
+from .literals import ChangeTypeType, FormatTypeType, locationTypeType
 from .type_defs import (
     CreateChangesetResponseTypeDef,
     GetProgrammaticAccessCredentialsResponseTypeDef,
@@ -52,7 +52,7 @@ class Exceptions:
 
 class FinSpaceDataClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace-data.html#FinSpaceData.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/finspace-data.html#FinSpaceData.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -61,23 +61,23 @@ class FinSpaceDataClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_changeset(
         self,
         datasetId: str,
-        changeType: ChangeType,
+        changeType: ChangeTypeType,
         sourceType: Literal["S3"],
         sourceParams: Dict[str, str],
-        formatType: FormatType = None,
+        formatType: FormatTypeType = None,
         formatParams: Dict[str, str] = None,
         tags: Dict[str, str] = None,
     ) -> CreateChangesetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
-        [Show boto3-stubs documentation](./client.md#create-changeset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
+        [Show boto3-stubs documentation](./client.md#create_changeset)
         """
 
     def generate_presigned_url(
@@ -88,22 +88,22 @@ class FinSpaceDataClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_programmatic_access_credentials(
         self, environmentId: str, durationInMinutes: int = None
     ) -> GetProgrammaticAccessCredentialsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
-        [Show boto3-stubs documentation](./client.md#get-programmatic-access-credentials)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
+        [Show boto3-stubs documentation](./client.md#get_programmatic_access_credentials)
         """
 
     def get_working_location(
-        self, locationType: locationType = None
+        self, locationType: locationTypeType = None
     ) -> GetWorkingLocationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
-        [Show boto3-stubs documentation](./client.md#get-working-location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
+        [Show boto3-stubs documentation](./client.md#get_working_location)
         """
